@@ -1,6 +1,6 @@
 ##############################################################################
 #
-# Copyright (c) 2006 Lovely Systems and Contributors.
+# Copyright (c) 2006 Zope Foundation and Contributors.
 # All Rights Reserved.
 #
 # This software is subject to the provisions of the Zope Public License,
@@ -11,19 +11,17 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""Tag test setup
+"""Tag test setup"""
 
-$Id: tests.py 90992 2008-09-09 10:34:36Z fafhrd $
-"""
-__docformat__ = "reStructuredText"
-
-import doctest, unittest
+import doctest
+import unittest
 
 
 def test_suite():
-
-    return unittest.TestSuite((
-        doctest.DocFileSuite(
-                'README.txt',
-                optionflags=doctest.NORMALIZE_WHITESPACE|doctest.ELLIPSIS),
-        ))
+    optionflags = (doctest.NORMALIZE_WHITESPACE | doctest.ELLIPSIS |
+                   doctest.REPORT_ONLY_FIRST_FAILURE)
+    return unittest.TestSuite([
+        doctest.DocFileSuite('README.txt', optionflags=optionflags),
+        doctest.DocFileSuite('subset.txt', optionflags=optionflags),
+        doctest.DocTestSuite('z3c.batching.batch', optionflags=optionflags),
+    ])
